package core.engine.terrain;

import core.engine.Loader;
import core.engine.entity.Entity;
import core.engine.model.HexagonModel;
import core.engine.model.RawModel;
import core.engine.model.TexturedModel;
import core.engine.textures.ModelTexture;
import utils.vectors.Vector3f;

import java.util.ArrayList;
import java.util.List;

public class Terrain {


    private final List<TerrainTile> terrainTiles;

    private Terrain(List<TerrainTile> terrainTiles) {
        this.terrainTiles = terrainTiles;
    }

    public static Terrain generateTerrain(Loader loader) {
        HexagonModel hexagonModel = new HexagonModel();
        RawModel hexagonRawModel = loader.loadToVAO(hexagonModel.getVertices(), hexagonModel.getTextureCoords(), hexagonModel.getNormals(), hexagonModel.getIndices());
        ModelTexture hexagonTexture = new ModelTexture(loader.loadTexture("white"));
        TexturedModel hexagontexturedModel = new TexturedModel(hexagonRawModel, hexagonTexture);

        List<TerrainTile> generatedTerrainTiles = new ArrayList<>();
        for(int y = -9; y<9; y++) {
            for(int x=-16; x<16; x++) {
                float xPos = x * 1.7319988f;
                if(y % 2 == 0) {
                    xPos -= 0.866f;
                }
                Vector3f randomColor = new Vector3f((float) Math.random(), (float) Math.random(), (float) Math.random());
                generatedTerrainTiles.add(new TerrainTile(hexagonRawModel, new Vector3f(xPos , 0, y * -1.4999994f), 0, 0, 0,1, randomColor));
            }
        }

        System.out.println(31 * 1.7319988f);

        return new Terrain(generatedTerrainTiles);
    }

    public List<TerrainTile> getTerrainTiles() {
        return terrainTiles;
    }
}
